"tan_d" <-
function(theta=0) {

  #=======================================================
  #
  #  TITLE:     COMPUTE TANGENT IN DEGREES
  #  FUNCTION:  tan_d()
  #  AUTHOR:    TARMO K. REMMEL 
  #  DATE:      16 JANUARY 2006
  #  CALLS:     NA
  #  NEEDS:     
  #  NOTES:     TO SIMPLIFY THE USE OF RADIANS IN R
  #
  #=======================================================

  return(tan(theta*pi/180))
  
} # END FUNCTION: tan_d
